import 'package:equatable/equatable.dart';
import 'package:flutter/foundation.dart';

import '../core/core.dart';
import '../models/models.dart';

class M4eTransactionResult extends Equatable {
  final M4eUniqueId from;
  final M4eUniqueId to;
  final M4eAmount amount;
  final DateTime at;
  final M4eTransactionType txType;
  final Map<String, dynamic> meta;

  const M4eTransactionResult({
    @required this.from,
    @required this.to,
    @required this.amount,
    @required this.at,
    @required this.txType,
    @required this.meta,
  });

  factory M4eTransactionResult.fromJson(Map<String, dynamic> json) {
    return M4eTransactionResult(
      from: M4eUniqueId.fromUniqueString(json['flow']['from']),
      to: M4eUniqueId.fromUniqueString(json['flow']['to']),
      amount: M4eAmount.fromJson(json['flow']['amount']),
      at: DateTimeConverter.fromTimestampSinceEpoch(json['flow']['at']),
      txType: M4eTransactionType.parse(json['txType']),
      meta: json['meta'],
    );
  }

  @override
  List<Object> get props => [from, to, amount, at, txType, meta];

  @override
  String toString() {
    return 'M4eTransactionResult(from: $from, to: $to, amount: $amount, at: $at, txType: ${txType.toString()}, meta: $meta)';
  }
}
